@@ -186,10 +186,13 @@ class IOBroker(object):
     def __init__(self,
                  addr=0x01000000,
                  broadcast=0xffffffff,
-                 ioloop=None):
+                 ioloop=None,
+                 control=None,
+                 secret=None):
         self.pid = os.getpid()
         self._stop_event = threading.Event()
         self._reload_event = threading.Event()
+        self.shutdown_flag = threading.Event()
         self.addr = addr
         self.broadcast = broadcast
         self.marshal = MarshalEnv()
@@ -221,15 +224,27 @@ class IOBroker(object):
                              for x in modules))
         self._cid = list(range(1024))
         # secret; write non-zero byte as terminator
-        self.secret = os.urandom(15)
-        self.secret += b'\xff'
+        if secret:
+            self.secret = secret
+        else:
+            self.secret = os.urandom(15)
+            self.secret += b'\xff'
         self.uuid = uuid.uuid4()
         # masquerade cache expiration
         self._expire_thread = Cache(self._stop_event)
         self._expire_thread.register_map(self.masquerade, self.nonces.free)
         self._expire_thread.register_map(self.packet_ids)
         self._expire_thread.setDaemon(True)
-        self.ioloop = ioloop or IOLoop()
+        if ioloop:
+            self.ioloop = ioloop
+            self.standalone = False
+        else:
+            self.ioloop = IOLoop()
+            self.standalone = True
+        if control:
+            self.add_client(control)
+            self.controls.add(control)
+            self.ioloop.register(control, self.route, defer=True)
 
     def handle_connect(self, fd, event):
         (client, addr) = fd.accept()
@@ -288,9 +303,9 @@ class IOBroker(object):
                 raise IOError(13, 'Permission denied')
 
             rsp['cmd'] = IPRCMD_ACK
+            rsp['attrs'].append(['IPR_ATTR_SOURCE', cmd['cmd']])
         except Exception:
-            rsp['attrs'] = [['IPR_ATTR_ERROR',
-                             traceback.format_exc()]]
+            rsp['attrs'] = [['IPR_ATTR_ERROR', traceback.format_exc()]]
 
         rsp.encode()
         ne = envmsg()
@@ -307,6 +322,9 @@ class IOBroker(object):
         ne.encode()
         sock.send(ne.buf.getvalue())
 
+        if self.shutdown_flag.is_set():
+            self.shutdown()
+
     def route_forward(self, sock, envelope):
         nonce = envelope['header']['sequence_number']
 
@@ -438,7 +456,7 @@ class IOBroker(object):
                 self.deregister_link(fd=sock)
             return
 
-        for envelope in self.marshal.parse(data):
+        for envelope in self.marshal.parse(data, sock):
             if envelope['id'] in self.packet_ids:
                 # drop duplicated packets
                 continue
@@ -545,7 +563,8 @@ class IOBroker(object):
 
     def start(self):
         self._expire_thread.start()
-        self.ioloop.start()
+        if self.standalone:
+            self.ioloop.start()
 
     def shutdown(self):
         self._stop_event.set()
@@ -553,3 +572,6 @@ class IOBroker(object):
             sock.close()
         # shutdown sequence
         self._expire_thread.join()
+        if self.standalone:
+            self.ioloop.shutdown()
+            self.ioloop.join()
