@@ -13,7 +13,7 @@ from pyroute2.common import basestring
 _letters = re.compile('[A-Za-z]')
 _fmt_letters = re.compile('[^!><@=][!><@=]')
 
-##  Netlink family
+#  Netlink family
 #
 NETLINK_ROUTE = 0            # Routing/device hook
 NETLINK_UNUSED = 1           # Unused number
@@ -376,7 +376,10 @@ class nlmsg_base(dict):
         '''
         Return the first attr by name or None
         '''
-        attrs = self.get_attrs(attr, fmt)
+        try:
+            attrs = self.get_attrs(attr, fmt)
+        except KeyError:
+            return default
         if attrs:
             return attrs[0]
         else:
